---
title: 네이버페이 주문형 · 결제형 차이점
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 네이버페이 주문형 · 결제형 차이점
  description: >-
    네이버페이에서 제공하는 주문형, 결제형, 종합형의 차이점을 안내해 드립니다. 네이버페이 정책에 따라 주문형, 결제형,종합형의 입점
    프로세스와 결제 프로세스 기준이 상이하오니 계약 시 참고하여 주세요.
  keywords:
    - 네이버페이
    - 주문형
    - 결제형
    - 차이점
tags:
  - 네이버페이(결제형)
  - 네이버페이(주문형)
  - 결제대행사 계약
pgCompanies:
  - 네이버페이(주문형)
  - 네이버페이(결제형)
searchTags:
  - 간편결제연동
  - 간편결제 연동
  - 간편결제
  - 네이버페이 연동
  - 네이버페이 종류
  - 네이버페이 이용방법
  - 주문형결제형
  - 주문형 결제형
  - 네이버페이 주문형
  - 네이버페이 결제형
  - 주문형
  - 결제형
  - 네이버페이 차이
  - 네이버페이
datetime: 2024-03-03T17:32:01.654Z
---

<Callout content="네이버페이는 결제방식에 따라 주문형과 결제형으로 나뉘어집니다. 네이버페이에서 고지하는 주문형과 결제형의 차이점을 안내드리오니 참고하시어 원하시는 유형으로 진행해주시기 바랍니다.
" title="" />

<Callout title="네이버페이 공지사항 보러가기↗" />

#### **주문형**

상품 페이지 내 \[네이버페이 구매하기] 버튼 이 노출되며 구매하기 버튼 클릭 시 네이버페이 주문서를 통해 주문을 진행하는 유형을 의미합니다.

#### **결제형**

고객이 결제수단을 고르는 페이지에서 \[네이버페이] 가 제공되어 주문이 진행되는 유형을 의미합니다.

#### **종합형**

상품페이지 내 \[네이버페이 구매하기] 버튼이 노출되고,  고객이 결제수단을 고르는 페이지에서도 \[네이버페이]가 제공되어 어느 페이지에서든 네이버페이 주문이 진행되는 유형을 의미합니다.

#### **주요 차이점**

- **\[주문형]** 방식은 배송 가능한 **'실물'** 상품을 운영할 때만 이용 가능합니다.
- \[**결제형]** 은 '실물' 및 '비실물' 상품 모두 가입이 가능합니다.
  - 실물상품 (배송가능한 상품) : 의류, 가구 등
  - 비실물상품 (컨텐츠) : 티켓, 서비스이용료, 회원권 등
- **\[결제형]** 은 고객사 자체 취소/반품/교환 정책을 적용할 수 있습니다.
- **\[결제형]** 입점 기준
  - 결제형 방식은 네이버페이 내부 정책에 따라 실 거래(매출)가 발생되어야 가입심사가 가능합니다.\
    (PG 거래데이터 증빙자료 제출 후 심사 진행)
  - 결제형 방식은 판매하시는 서비스 형태가 “통신판매중개업” 유형의 경우,월 평균 3000만원/보증보험 가입 조건으로 입점심사가 가능합니다. (2022년 7월 신설)
